pub trait PixelFormat { }Expand description
Represents an image pixel format to convert images into.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait PixelFormat { }Represents an image pixel format to convert images into.
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".