pub struct InlineRingBuffer<T, const SIZE: usize> { /* private fields */ }
A ring buffer that stores its contents inline.
Get a borrow to all the items in this ring buffer.
Get a mutable borrow to all the items in this ring buffer.
Get a borrow the current item.
Get a mutable borrow to the current item.
Move to the next item in the ring buffer.
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The alignment of pointer.
The type for initializers.
Initializes a with the given initializer.
Read more
Mutably dereferences the given pointer.
Read more
Drops the object pointed to by the given pointer.
Read more
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.